==> haskell-wai-app-static-3.1.9-214-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-Jy5a5GGwULNLjqNshucg7
key:                  wai-app-static-3.1.9-Jy5a5GGwULNLjqNshucg7
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  12b6eb071594afb84ee5dbcb0dde257e
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-Jy5a5GGwULNLjqNshucg7
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-A6Vi4VW5MkkDRUuOYiyz4t
    blaze-markup-0.8.3.0-4OBPTc45d0P9Dl7KWqlGv6 bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.4-3OO0UiAuNvXForiLKNIyZt
    directory-1.3.7.1 file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    filepath-1.4.2.2 http-date-0.0.11-CL0sHSTZcJG1TxXHK7tqdo
    http-types-0.12.4-5kbj0Cv0rp8HNRwQfelhRA
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    optparse-applicative-0.18.1.0-DIJ4MbtGu3QDLh3tqkvHS0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-compat-0.7.4.1-6c2cEqPZKnV3oQxTlqkOug
    unordered-containers-0.2.20.1-LlrDkEbe6ka5Vid8Nf7fMl
    wai-3.2.4-HbGzj3ODjKy9gf24pBgAvG
    wai-extra-3.1.18-EcRX4hxSfOt7Zv8HDVZhj
    warp-3.3.31-EuVFpHL4tC8B6O3zETiGa1
    zlib-0.7.0.0-CWCQOp9WY8aARLfbxZwOd5

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.9-215-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-KOQaih6mFA08v3j7hKjojt
key:                  wai-app-static-3.1.9-KOQaih6mFA08v3j7hKjojt
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  d55dce518803f9b1d8ee2a8e9ab8ff44
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-KOQaih6mFA08v3j7hKjojt
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-A6Vi4VW5MkkDRUuOYiyz4t
    blaze-markup-0.8.3.0-4OBPTc45d0P9Dl7KWqlGv6 bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.4-3OO0UiAuNvXForiLKNIyZt
    directory-1.3.7.1 file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    filepath-1.4.2.2 http-date-0.0.11-CL0sHSTZcJG1TxXHK7tqdo
    http-types-0.12.4-5kbj0Cv0rp8HNRwQfelhRA
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    optparse-applicative-0.18.1.0-DIJ4MbtGu3QDLh3tqkvHS0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-compat-0.7.4.1-6c2cEqPZKnV3oQxTlqkOug
    unordered-containers-0.2.20.1-LlrDkEbe6ka5Vid8Nf7fMl
    wai-3.2.4-HbGzj3ODjKy9gf24pBgAvG
    wai-extra-3.1.18-D5DmOlQnG9I32dkfA2Mp67
    warp-3.4.0-LYdxDOwOJ3v4yktLABaOuj
    zlib-0.7.0.0-CWCQOp9WY8aARLfbxZwOd5

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
